elephant\.current\_source\_density\_src\.basis\_functions module
================================================================

.. automodule:: elephant.current_source_density_src.basis_functions
    :members:
    :undoc-members:
    :show-inheritance:
